#!/usr/bin/env bash
VERSION=1.3.0
VENDOR=${VENDOR}
COMMIT_ID=${COMMIT_ID}
VENDOR_DIR="vscode-server"
if [[ "$VENDOR" == "cursor" ]]; then
    VENDOR_DIR="cursor-server"
fi
VENDOR_SERVER="code-server"
if [[ "$VENDOR" == "cursor" ]]; then
    VENDOR_SERVER="cursor-server"
fi

set -e

shopt -s nocasematch

check_server() {
    for i in {1..300}; do
        code_bin=`echo ~/.${VENDOR_DIR}/cli/servers/Stable-${COMMIT_ID}/server/bin/${VENDOR_SERVER}`
        if [[ -f $code_bin ]]; then
            return 0
        fi
        echo "Waiting for ${VENDOR_SERVER} to start..."
        sleep 3
    done
    return 1
}

check_extension() {
    code_bin=`echo ~/.${VENDOR_DIR}/cli/servers/Stable-${COMMIT_ID}/server/bin/${VENDOR_SERVER}`
    if $code_bin serve-local --accept-server-license-terms --list-extensions | grep -q "^zetyun.gpu-debugger-remote$"; then
        return 0
    fi
    return 1
}

replace_gallery() {
    if [[ "$VENDOR" == "cursor" ]]; then
        PRODUCT_JSON=$(echo ~/.${VENDOR_DIR}/cli/servers/Stable-${COMMIT_ID}/server/product.json)
        if [[ -f $PRODUCT_JSON.bak ]]; then
            cp $PRODUCT_JSON.bak $PRODUCT_JSON
        else
            cp -f $PRODUCT_JSON $PRODUCT_JSON.bak
        fi
        sed -i '/"extensionsGallery": {/,/},/c\
  "extensionsGallery": {\
    "galleryId": "cursor",\
    "nlsBaseUrl": "https://www.vscode-unpkg.net/_lp/",\
    "serviceUrl": "https://marketplace.visualstudio.com/_apis/public/gallery",\
    "itemUrl": "https://marketplace.visualstudio.com/items",\
    "publisherUrl": "https://marketplace.visualstudio.com/publishers",\
    "resourceUrlTemplate": "https://{publisher}.vscode-unpkg.net/{publisher}/{name}/{version}/{path}",\
    "extensionUrlTemplate": "https://www.vscode-unpkg.net/_gallery/{publisher}/{name}/latest",\
    "controlUrl": "https://main.vscode-cdn.net/extensions/marketplace.json"\
  },' "$PRODUCT_JSON"
    fi
}

restore_gallery() {
    if [[ "$VENDOR" == "cursor" ]]; then
        cp $PRODUCT_JSON.bak $PRODUCT_JSON
    fi
}

install_extension() {
    PLUGINS=(
        "ms-python.python"
        "ms-python.debugpy"
    )

    force_flag=false
    for arg in "$@"; do
        if [[ "$arg" == "--force" ]]; then
            force_flag=true
            break
        fi
    done

    replace_gallery
    
    code_bin=`echo ~/.${VENDOR_DIR}/cli/servers/Stable-${COMMIT_ID}/server/bin/${VENDOR_SERVER}`
    for plugin in "${PLUGINS[@]}"; do
        if $code_bin serve-local --accept-server-license-terms --list-extensions | grep -q "^$plugin$"; then
            echo "Extension $plugin was already installed, skip!"
        else
            echo "Installing extension $plugin..."
            $code_bin serve-local --accept-server-license-terms --install-extension "$plugin"
        fi
    done

    restore_gallery

    if $code_bin serve-local --accept-server-license-terms --list-extensions | grep -q "^zetyun.gpu-debugger-remote$"; then
        if ! $force_flag; then
        echo "remote.vsix was already installed, skip!"
        return
        fi
    fi

    $code_bin serve-local --accept-server-license-terms --uninstall-extension zetyun.gpu-debugger-remote || true

    $code_bin serve-local --accept-server-license-terms --install-extension /root/.alaya/vscode-plugin-remote/remote.vsix --force 
}

vscode_setting_json() {
    settings_file="/root/.${VENDOR_DIR}/data/Machine/settings.json"
    mkdir -p "$(dirname "$settings_file")"
    json_content='{
        "files.exclude": {
            "**/.*": true
        }
    }'
    if [[ ! -f "$settings_file" ]]; then
        echo "$json_content" > "$settings_file"
    fi
}

vscode_setting_json

case "$1" in
  check)
    case "$2" in
      remote)
        check_extension
        result=$?
        exit $result 
        ;;
      server)
        check_server
        result=$?
        exit $result 
        ;;
      *)
        echo "Unknown subcommand for $1: $2"
        exit 1
        ;;
    esac
    ;;
  install)
    case "$2" in
      remote)
        install_extension ${@:3}
        ;;
      *)
        echo "Unknown subcommand for $1: $2"
        exit 1
        ;;
    esac
    ;;
  *)
    echo "Error: Unknown command '$1'"
    exit 1
    ;;
esac